@@ -1,5 +1,5 @@
 # PyCO2SYS: marine carbonate system calculations in Python.
-# Copyright (C) 2020  Matthew Paul Humphreys et al.  (GNU GPLv3)
+# Copyright (C) 2020--2021  Matthew P. Humphreys et al.  (GNU GPLv3)
 """Helpers for the main CO2SYS program."""
 
 from autograd import numpy as np
@@ -48,6 +48,7 @@ def condition(input_locals, npts=None):
         "CARB",
         "HCO3",
         "CO2",
+        "XC",
         "TempC",
         "Pdbar",
         "TSi",
@@ -228,7 +229,7 @@ def _outputs_grad(args, core_in, core_out, others_in, others_out, totals, Kis, K
         "RFin": others_in["Revelle"],
         "OmegaCAin": others_in["OmegaCa"],
         "OmegaARin": others_in["OmegaAr"],
-        "xCO2in": others_in["xCO2dry"] * 1e6,
+        "xCO2in": core_in["XC"] * 1e6,
         "pHout": core_out["PH"],
         "pCO2out": core_out["PC"] * 1e6,
         "fCO2out": core_out["FC"] * 1e6,
@@ -245,7 +246,7 @@ def _outputs_grad(args, core_in, core_out, others_in, others_out, totals, Kis, K
         "RFout": others_out["Revelle"],
         "OmegaCAout": others_out["OmegaCa"],
         "OmegaARout": others_out["OmegaAr"],
-        "xCO2out": others_out["xCO2dry"] * 1e6,
+        "xCO2out": core_out["XC"] * 1e6,
         "pHinTOTAL": others_in["pHT"],
         "pHinSWS": others_in["pHS"],
         "pHinFREE": others_in["pHF"],
